<?php
/**
 * Functions.php contains all the core functions for your theme to work properly.
 * Please do not edit this file!!
 *
 * @package Photo WordPress Theme
 * @since 1.0
 * @author AJ Clarke : http://wpexplorer.com
 * @copyright Copyright (c) 2012, AJ Clarke
 * @link http://wpexplorer.com
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */
 
 

/**
* Define Constants
*/
define( 'WPEX_JS_DIR', get_template_directory_uri().'/js' );
define( 'WPEX_CSS_DIR', get_template_directory_uri().'/css' );

/**
* Get functions
* @since 1.0
*/

// Load admin panel
require_once ( get_template_directory() .'/functions/load-admin.php' );

// Add basic hooks
require_once ( get_template_directory() .'/functions/hooks.php' );

// Load CSS and JS
require_once( get_template_directory() .'/functions/scripts.php' );

// Setup some useful functions
require_once( get_template_directory() .'/functions/pagination.php' );
require_once( get_template_directory() .'/functions/img_resizer.php' );
require_once( get_template_directory() .'/functions/img_defaults.php' );
require_once( get_template_directory() .'/functions/wpex_comments_output.php' );

// Adds a feed metaboxes
require_once ( get_template_directory() .'/functions/dashboard-feed.php' );

// Splash Page
require_once ( get_template_directory() .'/functions/welcome.php' );

/**
* Theme Setup
*/


//Localization support
load_theme_textdomain( 'wpex', get_template_directory() .'/lang' );

function wpex_setup() {

	//default width of primary content area
	$content_width = 920;
	
	//theme support
	add_theme_support('automatic-feed-links');
	add_theme_support('custom-background');
	add_theme_support('post-thumbnails');
	
	//register navigation menus
	if ( ! function_exists ( 'wpex_register_nav_menus' ) ) {
		function wpex_register_nav_menus ( ) {
			$wpex_menus = array(
				'main_menu' => __( 'Main', 'wpex' )
			);
			$wpex_menus = apply_filters ( 'wpex_nav_menus', $wpex_menus );
			register_nav_menus ( $wpex_menus );
		}
	}
	wpex_register_nav_menus();

}
add_action( 'after_setup_theme', 'wpex_setup' );


/**
* Replace Soliloquy affilate
* @since 1.0
*/
add_filter( 'tgmsp_affiliate_url', 'test_affiliate_url' );
function test_affiliate_url() {
	return 'http://www.wpexplorer.com/soliloquy-wordpress-plugin';
}


/**
* Change default read more style
* @since 1.0
*/
if ( !function_exists( 'wpex_new_excerpt_more' ) ) :
	function wpex_new_excerpt_more($more) {
		global $post;
		return '...';
	}
	add_filter('excerpt_more', 'wpex_new_excerpt_more');
endif;


/**
* Add home page option to WordPress Menu
* @since 1.0
*/
add_filter( 'wp_page_menu_args', 'home_page_menu_args' );
function home_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}

/**
* Define Social Options For This Theme
* @since 1.0
*/
function wpex_get_social() {
	
	//define array of icons
	$social_icons = array(
			'addThis' => 'addThis',
			'behance' => 'behance',
			'blogger' => 'blogger',
			'delicious' => 'delicious',
			'deviantart' => 'deviantart',
			'digg' => 'digg',
			'dopplr' => 'dopplr',
			'dribbble' => 'dribbble',
			'evernote' => 'evernote',
			'facebook' => 'facebook',
			'flickr' => 'flickr',
			'forrst' => 'forrst',
			'gitHub' => 'gitHub',
			'google' => 'google',
			'grooveshark' => 'grooveshark',
			'instagram' => 'instagram',
			'lastfm' => 'lastfm',
			'linkedin' => 'linkedin',
			'myspace' => 'myspace',
			'pinterest' => 'pinterest',
			'paypal' => 'paypal',
			'picasa' => 'picasa',
			'pinterest' => 'pinterest',
			'posterous' => 'posterous',
			'reddit' => 'reddit',
			'sharethis' => 'sharethis',
			'skype' => 'skype',
			'soundcloud' => 'soundcloud',
			'spotify' => 'spotify',
			'stumbleupon' => 'stumbleupon',
			'tumblr' => 'tumblr',
			'twitter' => 'twitter',
			'viddler' => 'viddler',
			'vimeo' => 'vimeo',
			'virb' => 'virb',
			'windows' => 'windows',
			'wordPress' => 'wordPress',
			'youtube' => 'youtube',
			'zerply' => 'zerply',
			'rss' => 'rss',
			'mail' => 'mail' );
	
	//return array
	return apply_filters('wpex_get_social', $social_icons);
}
?>